@@ -83,6 +83,8 @@ class Site extends \Blue2\Common\Site
         add_image_size('primary-quote-image', 603, 651, true);
         add_image_size('secondary-quote-image', 1110, 444, true);
         add_image_size('numbered-carousel', 925, 614, true);
+        add_image_size('featured-quote-image', 766, 460, true);
+        add_image_size('board-image', 495, 545, true);
     }
 
     public static function acfImage($id, $size, $postID = null) {
